memento.base

Memoization library with many features.

memento.cache introduces Cache protocol that people need to extend when making extensions.

Memoization library with many features.

memento.cache introduces Cache protocol that people need to extend when making
extensions.
raw docstring

absentclj

Value that signals absent key.

Value that signals absent key.
sourceraw docstring

as-mapclj

(as-map icache)
(as-map icache segment)
source

base-create-cacheclj

(base-create-cache conf)

Create a cache.

A conf is a map of cache settings, see memento.config namespace for names of settings.

Create a cache.

A conf is a map of cache settings, see memento.config namespace for names of settings.
sourceraw docstring

cachedclj

(cached icache segment args)
source

confclj

(conf icache)
source

finalize-invalidation!cljmultimethod

Finalize a secondary-index invalidation for one cache backend type. Receives start state and whether matching entries should be invalidated.

Finalize a secondary-index invalidation for one cache backend type. Receives
start state and whether matching entries should be invalidated.
sourceraw docstring

if-cachedclj

(if-cached icache segment args)
source

invalidateclj

(invalidate icache segment)
(invalidate icache segment args)
source

invalidate-allclj

(invalidate-all icache)
source

new-cachecljmultimethod

Instantiate cache. Extension point, do not call directly.

Instantiate cache. Extension point, do not call directly.
sourceraw docstring

no-cacheclj

source

put-allclj

(put-all icache f args-to-vals)
source

start-secondary-invalidation!cljmultimethod

Begin a secondary-index invalidation for one cache backend type and return implementation-specific state. All backends are started before any invalidate call.

Begin a secondary-index invalidation for one cache backend type and return
implementation-specific state. All backends are started before any invalidate call.
sourceraw docstring

start-secondary-invalidation-all!clj

(start-secondary-invalidation-all! sec-ids)

Start a secondary-index invalidation on every registered cache backend type.

Returns a single-use function of one boolean: true finalizes the invalidation and ends the lockout, false ends the lockout without invalidating. See memento.core/start-invalidation! for the caller-facing contract.

Start a secondary-index invalidation on every registered cache backend type.

Returns a single-use function of one boolean: true finalizes the invalidation and
ends the lockout, false ends the lockout without invalidating. See
memento.core/start-invalidation! for the caller-facing contract.
sourceraw docstring

unwrap-metaclj

(unwrap-meta o)
source

cljdoc builds & hosts documentation for Clojure/Script libraries