Memoization library with many features.
memento.cache introduces Cache protocol that people need to extend when making extensions.
Memoization library with many features. memento.cache introduces Cache protocol that people need to extend when making extensions.
(base-create-cache conf)Create a cache.
A conf is a map of cache settings, see memento.config namespace for names of settings.
Create a cache. A conf is a map of cache settings, see memento.config namespace for names of settings.
Finalize a secondary-index invalidation for one cache backend type. Receives start state and whether matching entries should be invalidated.
Finalize a secondary-index invalidation for one cache backend type. Receives start state and whether matching entries should be invalidated.
Instantiate cache. Extension point, do not call directly.
Instantiate cache. Extension point, do not call directly.
Begin a secondary-index invalidation for one cache backend type and return implementation-specific state. All backends are started before any invalidate call.
Begin a secondary-index invalidation for one cache backend type and return implementation-specific state. All backends are started before any invalidate call.
(start-secondary-invalidation-all! sec-ids)Start a secondary-index invalidation on every registered cache backend type.
Returns a single-use function of one boolean: true finalizes the invalidation and ends the lockout, false ends the lockout without invalidating. See memento.core/start-invalidation! for the caller-facing contract.
Start a secondary-index invalidation on every registered cache backend type. Returns a single-use function of one boolean: true finalizes the invalidation and ends the lockout, false ends the lockout without invalidating. See memento.core/start-invalidation! for the caller-facing contract.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |